#
# spec file for package python-paho-mqtt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-paho-mqtt
Version:        1.6.1
Release:        2.12
Summary:        MQTT version 3.11 client class
License:        EPL-1.0
Group:          Development/Languages/Python
URL:            http://eclipse.org/paho
Source:         https://github.com/eclipse/paho.mqtt.python/archive/refs/tags/v%{version}.tar.gz#/paho-mqtt-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This code provides a client class which enable applications to connect to an
MQTT broker to publish messages, and to subscribe to topics and receive
published messages. It also provides some helper functions to make publishing
one off messages to an MQTT server very straightforward.

The MQTT protocol is a machine-to-machine (M2M)/"Internet of Things"
connectivity protocol. Designed as an extremely lightweight publish/subscribe
messaging transport, it is useful for connections with remote locations where
a small code footprint is required and/or network bandwidth is at a premium.

Paho is an Eclipse Foundation project.

%prep
%setup -q -n paho.mqtt.python-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Wed Dec  8 2021 pgajdos@suse.com
- %%check: test the package
* Tue Nov  9 2021 Adrian Schröter <adrian@suse.de>
- update to version 1.6.1:
  - Changed default TLS version to 1.2 instead of 1.0.
  - Fix incoming MQTT v5 messages with overall property length > 127 bytes being
    incorrectly decoded. Closes #541.
  - MQTTMessageInfo.wait_for_publish() and MQTTMessageInfo.is_published() will
    now raise exceptions if called when the publish call produced an error.
    Closes #550.
  - Remove periodic retry checks for outgoing messages with QoS>0. This means
    that outgoing messages will only be retried on the client reconnecting to
    the server. They will *not* be retried when the client is still connected.
  - The `rc` parameter in the `on_disconnect` callback now has meaningful values
    in the case of an error. Closes #441.
  - Callbacks can now be applied to client instances using decorators.
  - PUBACK messages are now sent to the broker only after the on_message
    callback has returned.
  - Raise exceptions when attempting to set MQTT v5 properties to forbidden
    values. Closes #586.
  - Callbacks can now be updated from within a callback.
  - Remove _out_packet_mutex and _current_out_packet_mutex and convert the
    _out_packet queue use to thread safe.
  - Add basic MQTT v5 support to the subscribe and publish helper functions.
    Closes #575.
  - Fix on_disconnect() sometimes calling the MQTT v3.x callback when it should
    call the MQTT v5 callback. Closes #570.
  - Big performance improvement when receiving large payloads, particularly for
    SSL. Closes #571,
  - Fix connecting with MQTT v5 to a broker that doesn't support MQTT v5.
    Closes #566.
  - Removed ancient Mosquitto compatibility class.
  - Fix exception on calling Client(client_id="", clean_session=False).
    Closes #520.
  - Experimental support for Websockets continuation frames. Closes #500.
    Closes #89.
  - `Properties.json()` now converts Correlation Data bytes() objects to hex.
    Closes #555.
  - Only use the internal sockpair wakeup when running with loop_start() or
    loop(). This removes problems when running with an external event loop.
  - Drain all of sockpairR bytes to avoid unnecessary wakeups and possible
    timeouts. Closes #563.
  - Add timeout to MQTTMessageInfo:wait_for_publish().
* Wed Sep 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.1:
  * Exceptions that occur in callbacks are no longer suppressed
    by default. They can optionally be suppressed by setting
    `client.suppress_exceptions = True`.
  * Fix PUBREL remaining length of > 2 not being accepted for
    MQTT v5 message flows.
* Thu Oct 31 2019 antoine.belvire@opensuse.org
- Update to version 1.5.0:
  * Add support for clean_session on subscribe helper
    (gh#eclipse/paho.mqtt.python#219).
  * Add support for non-standard bridge connection
    (gh#eclipse/paho.mqtt.python#282).
  * Fix hang with QoS 2 message and clean_session = False. The fix
    replace hang with message DROP. See README for known
    limitation (gh#eclipse/paho.mqtt.python#284,
    gh#eclipse/paho.mqtt.python#286).
  * Fix connection establishement timeout
    (gh#eclipse/paho.mqtt.python#291,
    gh#eclipse/paho.mqtt.python#288).
  * Add support for connecting through a proxy
    (gh#eclipse/paho.mqtt.python#315).
  * Add MQTT v5 support (gh#eclipse/paho.mqtt.python#334).
  * Improve error message when sending queue is full
    (gh#eclipse/paho.mqtt.python#378).
  * Improve error handling during initialization on edge case
    (gh#eclipse/paho.mqtt.python#387,
    gh#eclipse/paho.mqtt.python#388).
  * Allow to specify local client port used (similar to
    bind_address) (gh#eclipse/paho.mqtt.python#390).
  * Add method is_connected to know if MQTT connection is
    established (gh#eclipse/paho.mqtt.python#414).
  * Set connection timeout to keepalive
    (gh#eclipse/paho.mqtt.python#425).
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Sun Sep  2 2018 antoine.belvire@opensuse.org
- Update to version 1.4.0:
  * Fix hang when client restarted and broker resumed a session
    with Qos2 message.
  * Fix reconnection loop when a clean_session=True client
    reconnect while Qos2 message are being sent.
  * Catch and log any exception raised by user callback.
  * Improve support for external event loop (like asyncio).
  * Fix order of message with publish.multiple helper.
  * Fix hang on wait_for_published() on bad network.
  * Fix issue with Websocket payload size between 127 and 65536.
  * Closes socket in client destructor to avoid FD leak.
  * Fix uncaught timeout exception during connection.
  * Remove dup flag on PUBREL packet.
  * Use secure entropy source for Websocket mask_key (urandom).
  * Fix mid generation that was not thread-safe.
  * Replace print() statements with proper logging.
  * Allow insecure TLS on publish and subscribe helpers.
  * Allow to remove authentication (reset username to None).
  * Add support for the non-standard bridge mode.
* Sat Nov 18 2017 antoine.belvire@opensuse.org
- Update to version 1.3.1:
  * Fix reconnect_delay_set which ignored the max_delay.
  * Fix crash when connection is lost while trying to send message.
  * Fix issue with unicode topic when some character were
    multi-bytes UTF-8.
  * Fix issue with empty Client ID with broker that doesn't support
    them.
  * Fix issue with tls_set that did not allowed
    cert_reqs=ssl.CERT_NONE.
* Sat Jul  8 2017 antoine.belvire@opensuse.org
- Update to version 1.3.0:
  * Requires Python 2.7 or 3.4+.
  * Remove support for SSL without SSLContext (Requires Python
    2.7.9+ or 3.2+).
  * on_connect callback is now always called flags. Previously this
  * callback could accepts 3 OR 4 arguments, now it must accepts 4.
  * tls_insecure_set() must now be called *after* tls_set().
  * Allow username and password to be zero length (as opposed to
  * not being present).
  * Allow zero length client ids when using MQTT v3.1.1.
  * Add SSLContext support, including SNI.
  * Improved support for unicode topic and binary payload.
  * Allow arbitrary Websocket headers and path.
  * Fix issue with large inbound payload over Websocket.
  * Add exponential delay for reconnection.
  * Move unit tests to pytest and tox.
  * Add support for standard Python logging.
  * Fix duplicate incoming QoS==2 message.
* Sat Apr 22 2017 antoine.belvire@opensuse.org
- Update to version 1.2.3:
  * Fix possible hang of TLS connection during handshake.
  * Fix issue with publish helper with TLS connection.
  * Fix installation issue on non-UTF-8 system.
  * Fix non-working Websocket over TLS connection.
- Remove paho-mqtt-1.2.2-fix-readme-decoding.patch (fixed
  upstream).
* Fri Apr 14 2017 antoine.belvire@opensuse.org
- Update to version 1.2.2:
  * Fix message lost when using paho.mqtt.publish helper with
    QoS=0 message.
- Changes from version 1.2.1:
  * Handle unicode username and passwords correctly.
  * Fix handling of invalid UTF-8 topics on incoming messages - the
    library now does not attempt to decode the topic - this will
    happen when the user accesses msg.topic in the on_message
    callback. If the topic is not valid UTF-8, an exception will be
    raised.
  * Fix issue with WebSocket connection in case of network issue
    (timeout or connection broken).
  * Fix issue with SSL connection, where latest incoming message
    may be delayed or never processed.
  * Fix possible message lost with publish.single and
    publish.multiple.
- Add paho-mqtt-1.2.2-fix-readme-decoding.patch:
  * Fix error at build when using non-UTF8 locale.
* Sat Mar 18 2017 antoine.belvire@opensuse.org
- Convert package to python singlespec.
* Mon Feb 27 2017 antoine.belvire@opensuse.org
- Initial package: python-paho-mqtt-1.2
